==> openjdk-11_11.0.4+11.orig.tar.xz: openjdk-11-11.0.4+11/test/hotspot/jtreg/runtime/Metaspace/MaxMetaspaceSizeTest.java <==
/*
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import jdk.test.lib.process.ProcessTools;
import jdk.test.lib.process.OutputAnalyzer;

/*
 * @test MaxMetaspaceSizeTest
 * @requires vm.bits == 64 & vm.opt.final.UseCompressedOops == true
 * @bug 8087291
 * @library /test/lib
 * @run main/othervm MaxMetaspaceSizeTest
 */

public class MaxMetaspaceSizeTest {
    public static void main(String... args) throws Exception {
        ProcessBuilder pb = ProcessTools.createJavaProcessBuilder(
            "-Xmx1g",
            "-XX:InitialBootClassLoaderMetaspaceSize=4195328",
            "-XX:MaxMetaspaceSize=4195328",
            "-XX:+UseCompressedClassPointers",
            "-XX:CompressedClassSpaceSize=1g",
            "--version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());
        output.shouldContain("MaxMetaspaceSize is too small.");
    }
}

==> openjdk-15_15+36.orig.tar.xz: openjdk-15-15+36/test/hotspot/jtreg/runtime/Metaspace/MaxMetaspaceSizeTest.java <==
/*
 * Copyright (c) 2017, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import jdk.test.lib.process.ProcessTools;
import jdk.test.lib.process.OutputAnalyzer;

/*
 * @test MaxMetaspaceSizeTest
 * @requires vm.bits == 64 & vm.opt.final.UseCompressedOops == true
 * @bug 8087291
 * @library /test/lib
 * @run driver MaxMetaspaceSizeTest
 */

public class MaxMetaspaceSizeTest {
    public static void main(String... args) throws Exception {
        ProcessBuilder pb = ProcessTools.createJavaProcessBuilder(
            "-Xmx1g",
            "-XX:InitialBootClassLoaderMetaspaceSize=4195328",
            "-XX:MaxMetaspaceSize=4195328",
            "-XX:+UseCompressedClassPointers",
            "-XX:CompressedClassSpaceSize=1g",
            "--version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());
        output.shouldContain("MaxMetaspaceSize is too small.");
        output.shouldNotHaveExitValue(0);
    }
}
